@@ -14,6 +14,7 @@ from vnpy.trader.object import HistoryRequest
 from vnpy.trader.datafeed import BaseDatafeed, get_datafeed
 from vnpy.trader.database import BaseDatabase, get_database
 
+import vnpy_ctastrategy
 from vnpy_ctastrategy import CtaTemplate
 from vnpy_ctastrategy.backtesting import (
     BacktestingEngine,
@@ -83,8 +84,8 @@ class BacktesterEngine(BaseEngine):
         """
         Load strategy class from source code.
         """
-        app_path = Path(__file__).parent.parent
-        path1 = app_path.joinpath("vnpy_ctastrategy", "strategies")
+        app_path = Path(vnpy_ctastrategy.__file__).parent
+        path1 = app_path.joinpath("strategies")
         self.load_strategy_class_from_folder(path1, "vnpy_ctastrategy.strategies")
 
         path2 = Path.cwd().joinpath("strategies")
@@ -372,7 +373,7 @@ class BacktesterEngine(BaseEngine):
         end: datetime
     ):
         """
-        Query bar data from RQData.
+        执行下载任务
         """
         self.write_log(f"{vt_symbol}-{interval}开始下载历史数据")
 
@@ -391,20 +392,27 @@ class BacktesterEngine(BaseEngine):
             end=end
         )
 
-        contract = self.main_engine.get_contract(vt_symbol)
-
         try:
-            # If history data provided in gateway, then query
-            if contract and contract.history_data:
-                data = self.main_engine.query_history(
-                    req, contract.gateway_name
-                )
-            # Otherwise use RQData to query data
+            if interval == "tick":
+                data = self.datafeed.query_tick_history(req)
             else:
-                data = self.datafeed.query_bar_history(req)
+                contract = self.main_engine.get_contract(vt_symbol)
+
+                # If history data provided in gateway, then query
+                if contract and contract.history_data:
+                    data = self.main_engine.query_history(
+                        req, contract.gateway_name
+                    )
+                # Otherwise use RQData to query data
+                else:
+                    data = self.datafeed.query_bar_history(req)
 
             if data:
-                self.database.save_bar_data(data)
+                if interval == "tick":
+                    self.database.save_tick_data(data)
+                else:
+                    self.database.save_bar_data(data)
+
                 self.write_log(f"{vt_symbol}-{interval}历史数据下载完成")
             else:
                 self.write_log(f"数据下载失败，无法获取{vt_symbol}的历史数据")
