@@ -1,4 +1,5 @@
 import csv
+import subprocess
 from datetime import datetime, timedelta
 from copy import copy
 
@@ -9,7 +10,6 @@ from vnpy.trader.constant import Interval, Direction, Exchange
 from vnpy.trader.engine import MainEngine
 from vnpy.trader.ui import QtCore, QtWidgets, QtGui
 from vnpy.trader.ui.widget import BaseMonitor, BaseCell, DirectionCell, EnumCell
-from vnpy.trader.ui.editor import CodeEditor
 from vnpy.event import Event, EventEngine
 from vnpy.chart import ChartWidget, CandleItem, VolumeItem
 from vnpy.trader.utility import load_json, save_json
@@ -29,9 +29,9 @@ class BacktesterManager(QtWidgets.QWidget):
 
     setting_filename = "cta_backtester_setting.json"
 
-    signal_log = QtCore.pyqtSignal(Event)
-    signal_backtesting_finished = QtCore.pyqtSignal(Event)
-    signal_optimization_finished = QtCore.pyqtSignal(Event)
+    signal_log = QtCore.Signal(Event)
+    signal_backtesting_finished = QtCore.Signal(Event)
+    signal_optimization_finished = QtCore.Signal(Event)
 
     def __init__(self, main_engine: MainEngine, event_engine: EventEngine):
         """"""
@@ -183,10 +183,10 @@ class BacktesterManager(QtWidgets.QWidget):
         self.statistics_monitor = StatisticsMonitor()
 
         self.log_monitor = QtWidgets.QTextEdit()
-        self.log_monitor.setMaximumHeight(400)
 
         self.chart = BacktesterChart()
-        self.chart.setMinimumWidth(1000)
+        chart = QtWidgets.QVBoxLayout()
+        chart.addWidget(self.chart)
 
         self.trade_dialog = BacktestingResultDialog(
             self.main_engine,
@@ -211,19 +211,28 @@ class BacktesterManager(QtWidgets.QWidget):
         self.candle_dialog = CandleChartDialog()
 
         # Layout
-        vbox = QtWidgets.QVBoxLayout()
-        vbox.addWidget(self.statistics_monitor)
-        vbox.addWidget(self.log_monitor)
+        middle_vbox = QtWidgets.QVBoxLayout()
+        middle_vbox.addWidget(self.statistics_monitor)
+        middle_vbox.addWidget(self.log_monitor)
+
+        left_hbox = QtWidgets.QHBoxLayout()
+        left_hbox.addLayout(left_vbox)
+        left_hbox.addLayout(middle_vbox)
+
+        left_widget = QtWidgets.QWidget()
+        left_widget.setLayout(left_hbox)
+
+        right_vbox = QtWidgets.QHBoxLayout()
+        right_vbox.addWidget(self.chart)
+
+        right_widget = QtWidgets.QWidget()
+        right_widget.setLayout(right_vbox)
 
         hbox = QtWidgets.QHBoxLayout()
-        hbox.addLayout(left_vbox)
-        hbox.addLayout(vbox)
-        hbox.addWidget(self.chart)
+        hbox.addWidget(left_widget)
+        hbox.addWidget(right_widget)
         self.setLayout(hbox)
 
-        # Code Editor
-        self.editor = CodeEditor(self.main_engine, self.event_engine)
-
     def load_backtesting_setting(self):
         """"""
         setting = load_json(self.setting_filename)
@@ -306,10 +315,14 @@ class BacktesterManager(QtWidgets.QWidget):
     def start_backtesting(self):
         """"""
         class_name = self.class_combo.currentText()
+        if not class_name:
+            self.write_log("请选择要回测的策略")
+            return
+
         vt_symbol = self.symbol_line.text()
         interval = self.interval_combo.currentText()
-        start = self.start_date_edit.dateTime().toPyDateTime()
-        end = self.end_date_edit.dateTime().toPyDateTime()
+        start = self.start_date_edit.dateTime().toPython()
+        end = self.end_date_edit.dateTime().toPython()
         rate = float(self.rate_line.text())
         slippage = float(self.slippage_line.text())
         size = float(self.size_line.text())
@@ -390,8 +403,8 @@ class BacktesterManager(QtWidgets.QWidget):
         class_name = self.class_combo.currentText()
         vt_symbol = self.symbol_line.text()
         interval = self.interval_combo.currentText()
-        start = self.start_date_edit.dateTime().toPyDateTime()
-        end = self.end_date_edit.dateTime().toPyDateTime()
+        start = self.start_date_edit.dateTime().toPython()
+        end = self.end_date_edit.dateTime().toPython()
         rate = float(self.rate_line.text())
         slippage = float(self.slippage_line.text())
         size = float(self.size_line.text())
@@ -509,10 +522,19 @@ class BacktesterManager(QtWidgets.QWidget):
     def edit_strategy_code(self):
         """"""
         class_name = self.class_combo.currentText()
-        file_path = self.backtester_engine.get_strategy_class_file(class_name)
+        if not class_name:
+            return
 
-        self.editor.open_editor(file_path)
-        self.editor.show()
+        file_path = self.backtester_engine.get_strategy_class_file(class_name)
+        cmd = ["code", file_path]
+
+        p: subprocess.CompletedProcess = subprocess.run(cmd, shell=True)
+        if p.returncode:
+            QtWidgets.QMessageBox.warning(
+                self,
+                "启动代码编辑器失败",
+                "请检查是否安装了Visual Studio Code，并将其路径添加到了系统全局变量中！"
+            )
 
     def reload_strategy_class(self):
         """"""
